package acgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module type Type_system.SIG_ACCESSSource

exception Not_found
type t
val unfold_type_definition : int -> t -> Logic.Lambda.Lambda.stype

unfold_type_definition id t returns the actual type for the type defined by id as the identifier of a type definition in the signature t. Fails with "Bug" if id does not correspond to a type definition

val pp_type : t -> Format.formatter -> Logic.Lambda.Lambda.stype -> unit
val pp_term : t -> Format.formatter -> Logic.Lambda.Lambda.term -> unit